@@ -11,14 +11,8 @@
  * (at your option) any later version.
  */
 
-/// open device
-static void fs_open(char* device);
-
-/// close device
-static void fs_close();
-
 ///  readbitmap - read bitmap
-extern void readbitmap(char* device, image_head image_hdr, char* bitmap, int pui);
+extern void readbitmap(char* device, image_head image_hdr, unsigned long* bitmap, int pui);
 
 /// read super block and write to image head
 extern void initial_image_hdr(char* device, image_head* image_hdr);
